pub enum Error {
Show 20 variants
ConfigureSystem(Error),
CreateLegacyDevice(Error),
EventFd(Error),
EventManager(Error),
I8042Error(I8042DeviceError),
KernelFile(Error),
KvmContext(Error),
LegacyIOBus(Error),
LoadCommandline(Error),
RegisterMMIODevice(Error),
Serial(Error),
TimerFd(Error),
Vcpu(Error),
VcpuEvent(Error),
VcpuHandle(Error),
VcpuResume,
VcpuSpawn(Error),
Vm(Error),
VmmObserverInit(Error),
VmmObserverTeardown(Error),
}Expand description
Errors associated with the VMM internal logic. These errors cannot be generated by direct user input, but can result from bad configuration of the host (for example if Firecracker doesn’t have permissions to open the KVM fd).
Variants
ConfigureSystem(Error)
This error is thrown by the minimal boot loader implementation.
CreateLegacyDevice(Error)
Legacy devices work with Event file descriptors and the creation can fail because of resource exhaustion.
EventFd(Error)
Cannot read from an Event file descriptor.
EventManager(Error)
Polly error wrapper.
I8042Error(I8042DeviceError)
I8042 Error.
KernelFile(Error)
Cannot access kernel file.
KvmContext(Error)
Cannot open /dev/kvm. Either the host does not have KVM or Firecracker does not have permission to open the file descriptor.
LegacyIOBus(Error)
Cannot add devices to the Legacy I/O Bus.
LoadCommandline(Error)
Cannot load command line.
RegisterMMIODevice(Error)
Cannot add a device to the MMIO Bus.
Serial(Error)
Write to the serial console failed.
TimerFd(Error)
Cannot create Timer file descriptor.
Vcpu(Error)
Vcpu error.
VcpuEvent(Error)
Cannot send event to vCPU.
VcpuHandle(Error)
Cannot create a vCPU handle.
VcpuResume
vCPU resume failed.
VcpuSpawn(Error)
Cannot spawn a new Vcpu thread.
Vm(Error)
Vm error.
VmmObserverInit(Error)
Error thrown by observer object on Vmm initialization.
VmmObserverTeardown(Error)
Error thrown by observer object on Vmm teardown.